import { AccessTokens } from './mongodb';
import type AccessToken from '../types/AccessToken';
import { createHash } from 'crypto';

export const createAccessToken = async (accessToken: AccessToken) => {
    const newAccessToken = await (await AccessTokens()).insertOne(accessToken);
    return newAccessToken;
}

export const getAccessToken = async (accessToken: string) => {
    if(accessToken.split(".").length !== 4) return null;
    
    const type = accessToken.split(".")[0];
    const createdAt = new Date(Number(Buffer.from(accessToken.split(".")[1], 'base64url').toString()));
    const username = Buffer.from(accessToken.split(".")[2], 'base64url').toString();
    const random = accessToken.split(".")[3];
    const entropy = createHash("sha256").update(random).digest("hex");

    const accessTokens = await AccessTokens();
    return accessTokens.findOne({ $and: [
        { type },
        { createdAt },
        { username },
        { entropy }
    ] }) as Promise<AccessToken | null>;
}